---
name: Bug report
about: Create a report to help us improve
title: ''
labels: 'bug'
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment (please complete the following information):**
 - pyGSTi version [e.g. v0.9.7.4]
 - python version [e.g. 3.7, 2.7]
 - OS [e.g. OSX 10.14, Ubuntu 16.04 LTS]

**Additional context**
Add any other context about the problem here.
